# Digitalhub-ml Library

The Digitalhub-ml SDK library is used to manage entities and executions in Digitalhub from Python.
The Digitalhub-ml layer is the third layer of the Digitalhub ml platform, focused on machine learning functions.
It contains the ml entities and objects (Models) and the methods to manage them.

A more detailed description of the library can be found in the [official documentation](https://scc-digitalhub.github.io/docs/) of Digitalhub.
